import { useAjax } from "@/Hook/useAjax"
import { PromotionDataDay, getPromotionDataTencentDayListApi } from "@/services/gameData/adlist"
import { Drawer } from "antd"
import React, { useEffect, useState } from "react"
import TableData from "../../components/TableData"
import columns12 from './tableConfigDay'

interface Props {
    queryForm: PromotionDataDay
    adName: string,
    promotionId?: number
    onClose?: () => void
    visible?: boolean
}

/**
 * 广告每日监控
 * @returns 
 */
const DayAd: React.FC<Props> = ({ adName, queryForm, promotionId, onClose, visible }) => {

    /***********************************/
    const [data, setData] = useState<{ pageSize: number, pageNum: number, sortFiled?: string, sortType?: string }>({ pageNum: 1, pageSize: 100 })
    const getPromotionDataTencentDayList = useAjax((params) => getPromotionDataTencentDayListApi(params))
    /***********************************/

    useEffect(() => {
        let params = JSON.parse(JSON.stringify(queryForm))
        delete params.sortType
        delete params.sortFiled
        delete params.pageSize
        delete params.pageNum
        if (promotionId) {
            params.promotionId = promotionId
        }
        getPromotionDataTencentDayList.run({...params, ...data})
    }, [promotionId, queryForm, data])

    return <Drawer title={`${adName} 腾讯广告每日数据`} placement="right" width={'90%'} onClose={onClose} visible={visible}>
        <TableData
            scroll={{ x: 1000, y: 600 }}
            ajax={getPromotionDataTencentDayList}
            fixed={{ left: 3, right: 0 }}
            dataSource={getPromotionDataTencentDayList?.data?.records?.map((item: any, index: number) => ({ ...item, id:  Number(data.pageNum.toString() + index.toString()) }))}
            total={getPromotionDataTencentDayList?.data?.total}
            page={queryForm.pageNum}
            pageSize={queryForm.pageSize}
            title='腾讯广告每日监控'
            onChange={(props: any) => {
                let { pagination, sortData } = props
                let { current, pageSize } = pagination
                let newQueryForm = JSON.parse(JSON.stringify(data))
                if (sortData && sortData?.order) {
                    newQueryForm['sortType'] = sortData?.order === 'ascend' ? 'asc' : 'desc'
                    newQueryForm['sortFiled'] = sortData?.field
                } else {
                    delete newQueryForm['sortType']
                    delete newQueryForm['sortFiled']
                }
                newQueryForm.pageNum = current
                newQueryForm.pageSize = pageSize
                setData({ ...newQueryForm })
            }}
            config={columns12()}
            configName={'腾讯广告每日监控'}
        />
    </Drawer>
}

export default React.memo(DayAd)